# Tapen

Tapen is a tool for composing and printing labels on a tape witha specialized printers. At the moment only Brother printers are supported.

# Credits

* Dmitry Berezovsky (@corvis) - author and main maintainer
* Dominic Radermacher (blip@mockmoon-cybernetics.ch) - creator of libptouch, the source code of this library was used to understand the interface to Brotehr devices.
* [CLI Rack](https://github.com/corvis/cli-rack)

# Disclaimer

This module is licensed under MIT. This means you are free to use it in commercial projects.

The MIT license clearly explains that there is no warranty for this free software. Please see the included LICENSE file
for details.
